@@ -8,6 +8,6 @@ if TYPE_CHECKING:
 
 def op_EBLOCK(state: State) -> None:            
     state.require(state.in_action, 'Cannot end blocks outside actions.')
-    state.require(state.last_action._nested_blocks_count > 0, 'No more blocks to close', 'Try removing this statement.')
+    state.require(state.last_action.nested_blocks_count > 0, 'No more blocks to close', 'Try removing this statement.')
     
     state.last_action.end_block()
